@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 use JSON -convert_blessed_universally;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 # ATTRIBUTES
 
@@ -28,7 +28,7 @@ fun new_redis($self) {
   state $redis = Redis->new(
     # e.g. ZING_REDIS='server=127.0.0.1:9999,debug=0'
     map +($$_[0], $#{$$_[1]} ? $$_[1] : $$_[1][0]),
-    map [$$_[0], $$_[1] && [split /\|/, $$_[1]]],
+    map [$$_[0], [split /\|/, $$_[1]]],
     map [split /=/], split /,\s*/,
     $ENV{ZING_REDIS} || ''
   );
@@ -44,8 +44,8 @@ method dump(HashRef $data) {
   return JSON->new->allow_nonref->convert_blessed->encode($data);
 }
 
-method keys(Str $key) {
-  return [$self->redis->keys($self->term($key, '*'))];
+method keys(Str @keys) {
+  return [map $self->redis->keys($self->term(@$_)), [@keys], [@keys, '*']];
 }
 
 method pull(Str $key) {
@@ -188,7 +188,7 @@ The dump method encodes and returns the data provided as JSON.
 
 =head2 keys
 
-  keys(Str $key) : ArrayRef[Str]
+  keys(Str @keys) : ArrayRef[Str]
 
 The keys method returns a list of keys under the namespace of the datastore or
 provided key.
@@ -199,7 +199,7 @@ provided key.
 
   # given: synopsis
 
-  my $keys = $store->keys;
+  my $keys = $store->keys('nodel');
 
 =back
 
@@ -355,7 +355,7 @@ The size method returns the size of a list in the datastore.
 
   # given: synopsis
 
-  my $size = $store->size;
+  my $size = $store->size('collection');
 
 =back
 
